import { FASTElement } from '@microsoft/fast-element';
import { CriteriaSegmentedControlOption } from '../types';
/**
 * Main class which defines the criteria segmented control component.
 *
 * @remarks
 *
 * Displays segmented criteria and dispatches events with the selected criteria.
 *
 * @public
 *
 * @example
 * Example of using the component:
 * ```
 *
 * const toolbarOptions: CriteriaSegmentedControlOption[] = [
 *   { label: 'A', field: 'INSTRUMENT_ID', value: 'id1', serialiser: Serialisers.EQ },
 *   { label: 'B', field: 'INSTRUMENT_ID', value: 'id2', serialiser: Serialisers.EQ },
 *   { label: 'C', field: 'INSTRUMENT_ID', value: 'id3', serialiser: Serialisers.EQ },
 * ];
 *
 *  <criteria-segmented-control
 *    :criteriaOptions=${() => toolbarOptions}
 *    :value=${sync((x) => x.criteriaFilter)}
 *  >
 *    <label slot="label">Filter by instrument name</label>
 *  </criteria-segmented-control>
 * ```
 *
 */
export declare class CriteriaSegmentedControl extends FASTElement {
    criteriaOptions: CriteriaSegmentedControlOption[];
    value: string;
    valueChanged(): void;
    selectedLabel: string;
    selectedLabelChanged(): void;
    itemClickHandler(label: string): void;
    private createCriteria;
}
//# sourceMappingURL=criteria-segmented-control.d.ts.map