import { ExpressionBuilder } from './expression-builder';
import { Join } from './types';
import { ensureArray, isExpressionParams } from './utils';
/**
 * @public
 */
export const createFormCriteriaBuilder = (criteriaBuilder) => (config, formValue, formData) => {
    const { criteria: expressionsFactory } = config;
    let expressions = expressionsFactory(formValue, formData);
    if (isExpressionParams(expressions)) {
        expressions = [expressions];
    }
    expressions.map((expression) => {
        const [field, serialiser, value, condition, group] = expression;
        if (condition !== undefined && !condition) {
            return;
        }
        if (Array.isArray(field) || Array.isArray(value)) {
            criteriaBuilder.And(ensureArray(value).map((option) => ensureArray(field).map((fname) => new ExpressionBuilder()
                .withField(fname)
                .withValue(option)
                .withSerialiser(serialiser)
                .withGroup(group)
                .build())), { join: Join.Or() });
        }
        else {
            criteriaBuilder.And(new ExpressionBuilder()
                .withField(field)
                .withValue(value)
                .withSerialiser(serialiser)
                .withGroup(group)
                .build());
        }
    });
};
